summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/maps.cc
diff options
context:
space:
mode:
authorVsevolod Kozlov <zaba@wybt.net>2014-06-28 21:41:40 +0400
committerVsevolod Kozlov <zaba@wybt.net>2014-06-28 21:41:40 +0400
commitb2652204cafa35a4345d3183bf6d63da4cf61ae6 (patch)
tree215fdc488b95f9c78e24400a2202624f3f9cd690 /crawl-ref/source/maps.cc
parent96e6dfd7e2c6c1b35edeb9cb6e063c46494449d2 (diff)
downloadcrawl-ref-b2652204cafa35a4345d3183bf6d63da4cf61ae6.tar.gz
crawl-ref-b2652204cafa35a4345d3183bf6d63da4cf61ae6.zip
Rename the 'can_overwrite' vault tag to 'overwrite_floor_cell'.
In an attempt to clarify its new, more restricted behaviour.
Diffstat (limited to 'crawl-ref/source/maps.cc')
-rw-r--r--crawl-ref/source/maps.cc9
1 files changed, 5 insertions, 4 deletions
diff --git a/crawl-ref/source/maps.cc b/crawl-ref/source/maps.cc
index dcdf09a5b4..07329a200b 100644
--- a/crawl-ref/source/maps.cc
+++ b/crawl-ref/source/maps.cc
@@ -420,7 +420,7 @@ static bool _map_safe_vault_place(const map_def &map,
map.has_tag("water_ok") || player_in_branch(BRANCH_SWAMP);
const bool vault_can_overwrite_other_vaults =
- map.has_tag("can_overwrite");
+ map.has_tag("overwrite_floor_cell");
const bool vault_can_replace_portals =
map.has_tag("replace_portal");
@@ -446,9 +446,10 @@ static bool _map_safe_vault_place(const map_def &map,
}
else if (grd(cp) != DNGN_FLOOR || env.pgrid(cp) & FPROP_NO_TELE_INTO)
{
// Don't place can_overwrite vaults on anything but floor or on
// squares that can't be teleported into, because can_overwrite
// is used for things that are expected to be connected.
return false;
}
@@ -446,9 +446,10 @@ static bool _map_safe_vault_place(const map_def &map,
else if (grd(cp) != DNGN_FLOOR || env.pgrid(cp) & FPROP_NO_TELE_INTO)
{
- // Don't place can_overwrite vaults on anything but floor or on
- // squares that can't be teleported into, because can_overwrite
- // is used for things that are expected to be connected.
+ // Don't place overwrite_floor_cell vaults on anything but floor or
+ // on squares that can't be teleported into, because
+ // overwrite_floor_cell is used for things that are expected to be
+ // connected.
return false;
}